#####################################
AFG3152C Arbitrary function generator
#####################################

.. autoclass:: pymeasure.instruments.tektronix.AFG3152C
    :members:
    :show-inheritance:
